==> pipewire-docs-0.3.7-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Introduction", "index.html#sec_intro", null ],
    [ "Error reporting", "index.html#sec_errors", null ],
    [ "Logging", "index.html#sec_logging", null ],
    [ "Core API", "page_context_api.html", "page_context_api" ],
    [ "Control", "page_control.html", [
      [ "Overview", "page_control.html#page_control_overview", null ]
    ] ],
    [ "pw_core", "page_iface_pw_core.html", [
      [ "Description", "page_iface_pw_core.html#page_iface_pw_core_desc", null ],
      [ "API", "page_iface_pw_core.html#page_iface_pw_core", null ]
    ] ],
    [ "Registry", "page_registry.html", [
      [ "Overview", "page_registry.html#page_registry_overview", null ]
    ] ],
    [ "Proxy", "page_proxy.html", [
      [ "Overview", "page_proxy.html#sec_page_proxy_overview", null ],
      [ "Core proxy", "page_proxy.html#sec_page_proxy_core", null ],
      [ "Create", "page_proxy.html#sec_page_proxy_create", null ],
      [ "Bind", "page_proxy.html#sec_page_proxy_bind", null ],
      [ "Methods", "page_proxy.html#sec_page_proxy_methods", null ],
      [ "Events", "page_proxy.html#sec_page_proxy_events", null ],
      [ "Destroy", "page_proxy.html#sec_page_proxy_destroy", null ]
    ] ],
    [ "Media Streams", "page_streams.html", [
      [ "Overview", "page_streams.html#sec_overview", null ],
      [ "Create", "page_streams.html#sec_create", null ],
      [ "Connect", "page_streams.html#sec_connect", [
        [ "Stream target", "page_streams.html#ssec_stream_target", null ],
        [ "Stream formats", "page_streams.html#ssec_stream_formats", null ]
      ] ],
      [ "Format negotiation", "page_streams.html#sec_format", null ],
      [ "Buffer negotiation", "page_streams.html#sec_buffers", null ],
      [ "Streaming", "page_streams.html#sec_streaming", [
        [ "Consume data", "page_streams.html#ssec_consume", null ],
        [ "Produce data", "page_streams.html#ssec_produce", null ]
      ] ],
      [ "Disconnect", "page_streams.html#sec_stream_disconnect", null ]
    ] ],
    [ "Threaded Loop", "page_thread_loop.html", [
      [ "Overview", "page_thread_loop.html#sec_thread_loop_overview", null ],
      [ "Creation", "page_thread_loop.html#sec_thread_loop_create", null ],
      [ "Destruction", "page_thread_loop.html#sec_thread_loop_destruction", null ],
      [ "Locking", "page_thread_loop.html#sec_thread_loop_locking", null ],
      [ "Events and Callbacks", "page_thread_loop.html#sec_thread_loop_events", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
"global_8h.html#a48ade1ac8c560225b6d54dedbc48836a",
"impl-node_8c.html#a332223aa26f5d6c79181cf63e51b2bf6",
"link_8h.html#a7859f6eb040fead1673d0214b83b445b",
"permission_8h.html#a77df16320c3bb338666f55b2b21e6e47",
"stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08",
"structpw__factory__info.html",
"structpw__protocol__implementaton.html#a5dbc29661309ba54e93539eae72ba595"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-0.3.8-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Introduction", "index.html#sec_intro", null ],
    [ "Error reporting", "index.html#sec_errors", null ],
    [ "Logging", "index.html#sec_logging", null ],
    [ "Core API", "page_context_api.html", "page_context_api" ],
    [ "Control", "page_control.html", [
      [ "Overview", "page_control.html#page_control_overview", null ]
    ] ],
    [ "pw_core", "page_iface_pw_core.html", [
      [ "Description", "page_iface_pw_core.html#page_iface_pw_core_desc", null ],
      [ "API", "page_iface_pw_core.html#page_iface_pw_core", null ]
    ] ],
    [ "Registry", "page_registry.html", [
      [ "Overview", "page_registry.html#page_registry_overview", null ]
    ] ],
    [ "Proxy", "page_proxy.html", [
      [ "Overview", "page_proxy.html#sec_page_proxy_overview", null ],
      [ "Core proxy", "page_proxy.html#sec_page_proxy_core", null ],
      [ "Create", "page_proxy.html#sec_page_proxy_create", null ],
      [ "Bind", "page_proxy.html#sec_page_proxy_bind", null ],
      [ "Methods", "page_proxy.html#sec_page_proxy_methods", null ],
      [ "Events", "page_proxy.html#sec_page_proxy_events", null ],
      [ "Destroy", "page_proxy.html#sec_page_proxy_destroy", null ]
    ] ],
    [ "Media Streams", "page_streams.html", [
      [ "Overview", "page_streams.html#sec_overview", null ],
      [ "Create", "page_streams.html#sec_create", null ],
      [ "Connect", "page_streams.html#sec_connect", [
        [ "Stream target", "page_streams.html#ssec_stream_target", null ],
        [ "Stream formats", "page_streams.html#ssec_stream_formats", null ]
      ] ],
      [ "Format negotiation", "page_streams.html#sec_format", null ],
      [ "Buffer negotiation", "page_streams.html#sec_buffers", null ],
      [ "Streaming", "page_streams.html#sec_streaming", [
        [ "Consume data", "page_streams.html#ssec_consume", null ],
        [ "Produce data", "page_streams.html#ssec_produce", null ]
      ] ],
      [ "Disconnect", "page_streams.html#sec_stream_disconnect", null ]
    ] ],
    [ "Threaded Loop", "page_thread_loop.html", [
      [ "Overview", "page_thread_loop.html#sec_thread_loop_overview", null ],
      [ "Creation", "page_thread_loop.html#sec_thread_loop_create", null ],
      [ "Destruction", "page_thread_loop.html#sec_thread_loop_destruction", null ],
      [ "Locking", "page_thread_loop.html#sec_thread_loop_locking", null ],
      [ "Events and Callbacks", "page_thread_loop.html#sec_thread_loop_events", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
"global_8h.html#a3e5b2dd59d6cf7c614c3ed24b041a8b7",
"impl-node_8c.html#a2a6221b4e79357e3d2620faf0e2c7623",
"link_8h.html#a72d8e03483fd111c9a9eb87aac3897a2",
"permission_8h.html#a50224a8e3d16e9baa4be58183fec502f",
"stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68",
"structpw__factory__events.html#a2408a490257998e8aec63c452b450024",
"structpw__protocol__events.html#af7bb9abb40f974acecda6bb2c6ad5cad"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
